==> rcquant_sdk-0.0.240407.16.tar.gz: rcquant_sdk-0.0.240407.16/rcquant_sdk/data/market/fin_persist_save_param_data.py <==
from typing import List
from ...interface import IData
from ...packer.market.fin_persist_save_param_data_packer import FinPersistSaveParamDataPacker
from .fin_persist_filed_data import FinPersistFiledData


class FinPersistSaveParamData(IData):
    def __init__(self, table_name: str = '', range: str = '',
                 append: bool = False, basepath: str = '', vacuum: bool = False):
        super().__init__(FinPersistSaveParamDataPacker(self))
        self._TableName: str = table_name
        self._Range: str = range
        self._Fileds: List[FinPersistFiledData] = []
        self._Append: bool = append
        self._BasePath: str = basepath
        self._Vacuum: bool = False

    @property
    def TableName(self):
        return self._TableName

    @TableName.setter
    def TableName(self, value: str):
        self._TableName = value

    @property
    def Range(self):
        return self._Range

    @Range.setter
    def Range(self, value: str):
        self._Range = value

    @property
    def Fileds(self):
        return self._Fileds

    @Fileds.setter
    def Fileds(self, value: List[FinPersistFiledData]):
        self._Fileds = value

    @property
    def Append(self):
        return self._Append

    @Append.setter
    def Append(self, value: bool):
        self._Append = value

    @property
    def BasePath(self):
        return self._BasePath

    @BasePath.setter
    def BasePath(self, value: str):
        self._BasePath = value

    @property
    def Vacuum(self):
        return self._Vacuum

    @Vacuum.setter
    def Vacuum(self, value: bool):
        self._Vacuum = value

==> rcquant_sdk-0.0.240918.17.tar.gz: rcquant_sdk-0.0.240918.17/rcquant_sdk/data/market/fin_persist_save_param_data.py <==
from typing import List
from ...interface import IData
from ...packer.market.fin_persist_save_param_data_packer import FinPersistSaveParamDataPacker
from .fin_persist_filed_data import FinPersistFiledData


class FinPersistSaveParamData(IData):
    def __init__(self, instrument_id: str = '', period: str = '',
                 append: bool = False, vacuum: bool = False, base_path: str = ''):
        super().__init__(FinPersistSaveParamDataPacker(self))
        self._InstrumentID: str = instrument_id
        self._Period: str = period
        self._Fileds: List[FinPersistFiledData] = []
        self._Append: bool = append
        self._Vacuum: bool = vacuum
        self._BasePath: str = base_path

    @property
    def InstrumentID(self):
        return self._InstrumentID

    @InstrumentID.setter
    def InstrumentID(self, value: str):
        self._InstrumentID = value

    @property
    def Period(self):
        return self._Period

    @Period.setter
    def Period(self, value: str):
        self._Period = value

    @property
    def Fileds(self):
        return self._Fileds

    @Fileds.setter
    def Fileds(self, value: List[FinPersistFiledData]):
        self._Fileds = value

    @property
    def Append(self):
        return self._Append

    @Append.setter
    def Append(self, value: bool):
        self._Append = value

    @property
    def Vacuum(self):
        return self._Vacuum

    @Vacuum.setter
    def Vacuum(self, value: bool):
        self._Vacuum = value

    @property
    def BasePath(self):
        return self._BasePath

    @BasePath.setter
    def BasePath(self, value: int):
        self._BasePath = value
